WorkoutConfig class

Constructors

WorkoutConfig({required int week, required BodyZone bodyZone, required WorkoutDifficulty difficultyLevel, required WorkoutDuration workoutDuration, required String programID})

Properties

bodyZone BodyZone
getter/setter pair
difficultyLevel WorkoutDifficulty
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
programID String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
week int
getter/setter pair
workoutDuration WorkoutDuration
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited